# Changelog

<p align = "justify">All notable changes is documented here. The format is based on <a href = "https://keepachangelog.com/en/1.0.0/">Keep a Changelog</a>, and the project adheres to <a href = "https://semver.org/spec/v2.0.0.html">Semantic Versioning</a>.</p>

## [0.0.1-beta] - 2021-10-01
First **BETA** that needs rigorous testing and updates.

### Added
- basic design of `API` object that can be used for fetching data,
- defination of `errors` to make end-user understand in case of an error.

## Planning Stage
<p align = "justify">Building a python wrapper for fetching weather data (historical and/or forecast) from <a href = "https://www.visualcrossing.com/weather-data">VisualCrossing</a>. The wrapper is being developed in <i>python</i> since weather data is needed by everyone (like data science projects, etc.) and a python developer can easily fetch data without going through the huge well-defined <a href = "https://www.visualcrossing.com/resources/documentation/weather-api/weather-api-documentation/">documentation</a> for retreiving data. The module is also kept simple so that anyone can start querying immediately.</p>

<!-- Reference Links -->
[0.0.1-beta]: https://github.com/ZenithClown/VisualCrossing/releases/tag/v0.0.1-beta
